@@ -1,27 +1,13 @@
 /*
-    Copyright 2012 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2012 Frederik Gladhorn <gladhorn@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "accessibleobject.h"
 
-#include <qstring.h>
-#include <qdebug.h>
+#include <QString>
+#include <QDebug>
 
 #include "accessibleobject_p.h"
 #include "registry_p.h"
@@ -142,6 +128,11 @@ int AccessibleObject::indexInParent() const
     return d->registryPrivate->indexInParent(*this);
 }
 
+QString AccessibleObject::accessibleId() const
+{
+    return d->registryPrivate->accessibleId(*this);
+}
+
 QString AccessibleObject::name() const
 {
     return d->registryPrivate->name(*this);
