@@ -1,45 +1,29 @@
 /*
-    Copyright 2012 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2012 Frederik Gladhorn <gladhorn@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "registry_p.h"
 #include "registry.h"
 
-#include <qdbusmessage.h>
-#include <qdbusargument.h>
-#include <qdbusreply.h>
-#include <qdbuspendingcall.h>
-#include <qdbusinterface.h>
-#include <qdbusargument.h>
-#include <qdbusmetatype.h>
+#include <QDBusMessage>
+#include <QDBusArgument>
+#include <QDBusReply>
+#include <QDBusPendingCall>
+#include <QDBusInterface>
+#include <QDBusArgument>
+#include <QDBusMetaType>
 
-#include <qdebug.h>
-#include <qdbusmessage.h>
-#include <qstringlist.h>
+#include <QDebug>
+#include <QDBusMessage>
+#include <QStringList>
 #include <qurl.h>
 
 #include "atspi/atspi-constants.h"
-#include "atspi/qt-atspi.h"
-#include "atspi/dbusconnection.h"
 
-#include <qstring.h>
-#include <qhash.h>
+#include <QString>
+#include <QHash>
 
 // interface names from at-spi2-core/atspi/atspi-misc-private.h
 #define ATSPI_DBUS_NAME_REGISTRY "org.a11y.atspi.Registry"
@@ -97,7 +81,7 @@ RegistryPrivate::RegistryPrivate(Registry *qq)
     qDBusRegisterMetaType<QVector<quint32> >();
 
     connect(&conn, SIGNAL(connectionFetched()), this, SLOT(connectionFetched()));
-    connect(&m_actionMapper, SIGNAL(mapped(QString)), this, SLOT(actionTriggered(QString)));
+    connect(&m_actionMapper, SIGNAL(mappedString(QString)), this, SLOT(actionTriggered(QString)));
     init();
 }
 
@@ -197,7 +181,7 @@ void RegistryPrivate::connectionFetched()
 
     if (m_pendingSubscriptions > 0) {
         subscribeEventListeners(m_pendingSubscriptions);
-        m_pendingSubscriptions = nullptr;
+        m_pendingSubscriptions = {};
     }
 }
 
@@ -387,7 +371,7 @@ void RegistryPrivate::subscribeEventListeners(const Registry::EventListeners &li
         if (!success) qWarning() << "Could not subscribe to accessibility PropertyChange events.";
     }
 
-    Q_FOREACH(const QString &subscription, newSubscriptions) {
+    for (const QString &subscription : std::as_const(newSubscriptions)) {
         QDBusMessage m = QDBusMessage::createMethodCall(QLatin1String("org.a11y.atspi.Registry"),
                                                         QLatin1String("/org/a11y/atspi/registry"),
                                                         QLatin1String("org.a11y.atspi.Registry"), QLatin1String("RegisterEvent"));
@@ -398,7 +382,7 @@ void RegistryPrivate::subscribeEventListeners(const Registry::EventListeners &li
         QObject::connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher*)), this, SLOT(slotSubscribeEventListenerFinished(QDBusPendingCallWatcher*)));
     }
 
-    Q_FOREACH(const QString &subscription, removedSubscriptions) {
+    for (const QString &subscription : std::as_const(removedSubscriptions)) {
         QDBusMessage m = QDBusMessage::createMethodCall(QLatin1String("org.a11y.atspi.Registry"),
                                                         QLatin1String("/org/a11y/atspi/registry"),
                                                         QLatin1String("org.a11y.atspi.Registry"), QLatin1String("DeregisterEvent"));
@@ -466,15 +450,15 @@ void RegistryPrivate::a11yConnectionChanged(const QString &interface,const QVari
     if (interface == QLatin1String("org.a11y.Status")) {
         QVariantMap::ConstIterator IsEnabledIt = changedProperties.constFind(QLatin1String("IsEnabled"));
         if (IsEnabledIt != changedProperties.constEnd())
-            emit q->enabledChanged(IsEnabledIt.value().toBool());
+            Q_EMIT q->enabledChanged(IsEnabledIt.value().toBool());
         else if (invalidatedProperties.contains(QLatin1String("IsEnabled")))
-            emit q->enabledChanged(isEnabled());
+            Q_EMIT q->enabledChanged(isEnabled());
 
         QVariantMap::ConstIterator ScreenReaderEnabledIt = changedProperties.constFind(QLatin1String("ScreenReaderEnabled"));
         if (ScreenReaderEnabledIt != changedProperties.constEnd())
-            emit q->screenReaderEnabledChanged(ScreenReaderEnabledIt.value().toBool());
+            Q_EMIT q->screenReaderEnabledChanged(ScreenReaderEnabledIt.value().toBool());
         else if (invalidatedProperties.contains(QLatin1String("ScreenReaderEnabled")))
-            emit q->screenReaderEnabledChanged(isScreenReaderEnabled());
+            Q_EMIT q->screenReaderEnabledChanged(isScreenReaderEnabled());
     }
 }
 
@@ -553,7 +537,7 @@ QList<AccessibleObject> RegistryPrivate::children(const AccessibleObject &object
     }
 
     const QSpiObjectReferenceList children = reply.value();
-    Q_FOREACH(const QSpiObjectReference &child, children) {
+    for (const QSpiObjectReference &child : children) {
         accs.append(AccessibleObject(const_cast<RegistryPrivate*>(this), child.service, child.path.path()));
     }
 
@@ -567,6 +551,13 @@ QList<AccessibleObject> RegistryPrivate::topLevelAccessibles() const
     return children(AccessibleObject(const_cast<RegistryPrivate*>(this), service, path));
 }
 
+QString RegistryPrivate::accessibleId(const AccessibleObject &object) const
+{
+    if (!object.isValid())
+        return QString();
+    return getProperty(object.d->service, object.d->path, QLatin1String("org.a11y.atspi.Accessible"), QLatin1String("AccessibleId")).toString();
+}
+
 QString RegistryPrivate::name(const AccessibleObject &object) const
 {
     if (!object.isValid())
@@ -868,7 +859,8 @@ AccessibleObject::Interfaces RegistryPrivate::supportedInterfaces(const Accessib
     }
 
     AccessibleObject::Interfaces interfaces = AccessibleObject::NoInterface;
-    Q_FOREACH(const QString &interface, reply.value()){
+    const auto values{reply.value()};
+    for (const QString &interface : values){
         interfaces |= interfaceHash[interface];
     }
 
@@ -983,7 +975,7 @@ QString RegistryPrivate::textWithBoundary(const AccessibleObject &object, int of
     QDBusMessage message = QDBusMessage::createMethodCall(object.d->service, object.d->path, QLatin1String("org.a11y.atspi.Text"), QLatin1String("GetTextAtOffset"));
     message.setArguments(QVariantList() << offset << static_cast<AtspiTextBoundaryType>(boundary));
     QDBusMessage reply = conn.connection().call(message);
-    if (reply.type() != QDBusMessage::ReplyMessage || reply.signature() != QStringLiteral("sii")) {
+    if (reply.type() != QDBusMessage::ReplyMessage || reply.signature() != QLatin1String("sii")) {
         qWarning() << "Could not access text." << reply.errorMessage();
         if (startOffset)
             *startOffset = 0;
@@ -1315,87 +1307,87 @@ AccessibleObject RegistryPrivate::accessibleFromContext() const
 
 void RegistryPrivate::slotWindowCreate(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &)
 {
-    emit q->windowCreated(accessibleFromContext());
+    Q_EMIT q->windowCreated(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowDestroy(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowDestroyed(accessibleFromContext());
+    Q_EMIT q->windowDestroyed(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowClose(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowClosed(accessibleFromContext());
+    Q_EMIT q->windowClosed(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowReparent(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowReparented(accessibleFromContext());
+    Q_EMIT q->windowReparented(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowMinimize(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowMinimized(accessibleFromContext());
+    Q_EMIT q->windowMinimized(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowMaximize(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowMaximized(accessibleFromContext());
+    Q_EMIT q->windowMaximized(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowRestore(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowRestored(accessibleFromContext());
+    Q_EMIT q->windowRestored(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowActivate(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowActivated(accessibleFromContext());
+    Q_EMIT q->windowActivated(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowDeactivate(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowDeactivated(accessibleFromContext());
+    Q_EMIT q->windowDeactivated(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowDesktopCreate(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowDesktopCreated(accessibleFromContext());
+    Q_EMIT q->windowDesktopCreated(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowDesktopDestroy(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowDesktopDestroyed(accessibleFromContext());
+    Q_EMIT q->windowDesktopDestroyed(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowRaise(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowRaised(accessibleFromContext());
+    Q_EMIT q->windowRaised(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowLower(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowLowered(accessibleFromContext());
+    Q_EMIT q->windowLowered(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowMove(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowMoved(accessibleFromContext());
+    Q_EMIT q->windowMoved(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowResize(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowResized(accessibleFromContext());
+    Q_EMIT q->windowResized(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowShade(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowShaded(accessibleFromContext());
+    Q_EMIT q->windowShaded(accessibleFromContext());
 }
 
 void RegistryPrivate::slotWindowUnshade(const QString &state, int detail1, int detail2, const QDBusVariant &/*args*/, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->windowUnshaded(accessibleFromContext());
+    Q_EMIT q->windowUnshaded(accessibleFromContext());
 }
 
 void RegistryPrivate::slotPropertyChange(const QString &property, int detail1, int detail2, const QDBusVariant &args, const QSpiObjectReference &reference)
@@ -1404,9 +1396,9 @@ void RegistryPrivate::slotPropertyChange(const QString &property, int detail1, i
     qDebug() << Q_FUNC_INFO << property << detail1 << detail2 << args.variant() << reference.path.path();
 #endif
     if (property == QLatin1String("accessible-name")) {
-        emit q->accessibleNameChanged(accessibleFromContext());
+        Q_EMIT q->accessibleNameChanged(accessibleFromContext());
     } else if (property == QLatin1String("accessible-description")) {
-        emit q->accessibleDescriptionChanged(accessibleFromContext());
+        Q_EMIT q->accessibleDescriptionChanged(accessibleFromContext());
     }
 }
 
@@ -1429,17 +1421,17 @@ void RegistryPrivate::slotStateChanged(const QString &state, int detail1, int de
 
     if (state == QLatin1String("focused") && (detail1 == 1) &&
             (q->subscribedEventListeners().testFlag(Registry::Focus))) {
-        emit q->focusChanged(accessible);
+        Q_EMIT q->focusChanged(accessible);
     }
 
     if (q->subscribedEventListeners().testFlag(Registry::StateChanged)) {
-        emit q->stateChanged(accessible, state, detail1 == 1);
+        Q_EMIT q->stateChanged(accessible, state, detail1 == 1);
     }
 }
 
 // void RegistryPrivate::slotLinkSelected(const QString &/*state*/, int /*detail1*/, int /*detail2*/, const QDBusVariant &args, const QAccessibleClient::QSpiObjectReference &reference)
 // {
-//     emit q->linkSelected(accessibleFromContext());
+//     Q_EMIT q->linkSelected(accessibleFromContext());
 // }
 
 bool RegistryPrivate::removeAccessibleObject(const QAccessibleClient::AccessibleObject &accessible)
@@ -1448,10 +1440,10 @@ bool RegistryPrivate::removeAccessibleObject(const QAccessibleClient::Accessible
     if (m_cache) {
         const QString id = accessible.id();
         if (m_cache->remove(id)) {
-            emit q->removed(accessible);
+            Q_EMIT q->removed(accessible);
         }
     } else {
-        emit q->removed(accessible);
+        Q_EMIT q->removed(accessible);
     }
     if (accessible.d)
         accessible.d->setDefunct();
@@ -1479,9 +1471,9 @@ void RegistryPrivate::slotChildrenChanged(const QString &state, int detail1, int
 
     int index = detail1;
     if (state == QLatin1String("add")) {
-        emit q->childAdded(parentAccessible, index);
+        Q_EMIT q->childAdded(parentAccessible, index);
     } else if (state == QLatin1String("remove")) {
-        emit q->childRemoved(parentAccessible, index);
+        Q_EMIT q->childRemoved(parentAccessible, index);
     } else {
         qWarning() << "Invalid state in ChildrenChanged." << state;
     }
@@ -1489,27 +1481,27 @@ void RegistryPrivate::slotChildrenChanged(const QString &state, int detail1, int
 
 void RegistryPrivate::slotVisibleDataChanged(const QString &/*state*/, int /*detail1*/, int /*detail2*/, const QDBusVariant &args, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->visibleDataChanged(accessibleFromContext());
+    Q_EMIT q->visibleDataChanged(accessibleFromContext());
 }
 
 void RegistryPrivate::slotSelectionChanged(const QString &/*state*/, int /*detail1*/, int /*detail2*/, const QDBusVariant &args, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->selectionChanged(accessibleFromContext());
+    Q_EMIT q->selectionChanged(accessibleFromContext());
 }
 
 void RegistryPrivate::slotModelChanged(const QString &/*state*/, int /*detail1*/, int /*detail2*/, const QDBusVariant &args, const QAccessibleClient::QSpiObjectReference &reference)
 {
-    emit q->modelChanged(accessibleFromContext());
+    Q_EMIT q->modelChanged(accessibleFromContext());
 }
 
 void RegistryPrivate::slotTextCaretMoved(const QString &/*state*/, int detail1, int /*detail2*/, const QDBusVariant &/*args*/, const QSpiObjectReference &reference)
 {
-    emit q->textCaretMoved(accessibleFromContext(), detail1);
+    Q_EMIT q->textCaretMoved(accessibleFromContext(), detail1);
 }
 
 void RegistryPrivate::slotTextSelectionChanged(const QString &/*state*/, int /*detail1*/, int /*detail2*/, const QDBusVariant &/*args*/, const QSpiObjectReference &reference)
 {
-    emit q->textSelectionChanged(accessibleFromContext());
+    Q_EMIT q->textSelectionChanged(accessibleFromContext());
 }
 
 void RegistryPrivate::slotTextChanged(const QString &change, int start, int end, const QDBusVariant &textVariant, const QSpiObjectReference &reference)
@@ -1518,11 +1510,11 @@ void RegistryPrivate::slotTextChanged(const QString &change, int start, int end,
     QString text = textVariant.variant().toString();
 
     if (change == QLatin1String("insert")) {
-        emit q->textInserted(object, text, start, end);
+        Q_EMIT q->textInserted(object, text, start, end);
     } else if (change == QLatin1String("remove")) {
-        emit q->textRemoved(object, text, start, end);
+        Q_EMIT q->textRemoved(object, text, start, end);
     } else {
-        emit q->textChanged(object, text, start, end);
+        Q_EMIT q->textChanged(object, text, start, end);
     }
 }
 
